#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-CVISLpv0etQIPQ9ZaZT4rj
key:                  io-streams-haproxy-1.0.1.0-CVISLpv0etQIPQ9ZaZT4rj
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  28302a4b417430899a55c9c2819c3417
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.6.6/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/io-streams-haproxy-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-CVISLpv0etQIPQ9ZaZT4rj
depends:
    attoparsec-0.14.4-8yfReFQVnRV5DMGjEfnPOW base-4.18.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-EO3C5N7i0V5F8NXDXoj82p
    network-3.1.4.0-F5hgFLxNbdiMTTF4ZJb4k transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

